@@ -21,13 +21,21 @@ rm_lineartrend = \(formula,data,method = c("cpp","r")){
   }
 
   formulaname = formula_varname(formula,data)
+  xymat = as.matrix(data[,c(formulaname[[1]],
+                            formulaname[[2]])
+                         ])
+  notNAIndice = apply(xymat, 1, \(.x) all(!is.na(.x)))
   yvec = data[,formulaname[[1]],drop = TRUE]
+  ypredRM = rep(NA,times = length(yvec))
 
   if (method == "r"){
-    lm_model = stats::lm(formula,data)
-    return(yvec - stats::predict(lm_model))
+    lm_model = stats::lm(formula,data[notNAIndice,])
+    ypredRM[notNAIndice] = yvec[notNAIndice] - stats::predict(lm_model)
   } else {
     xmat = as.matrix(data[,formulaname[[2]]])
-    return(as.double(LinearTrendRM(yvec,xmat)))
+    ypredRM[notNAIndice] = as.double(LinearTrendRM(yvec[notNAIndice],
+                                                   xmat[notNAIndice,]))
   }
+
+  return(ypredRM)
 }
